'''OpenGL extension ARB.base_instance

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.base_instance to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows the offset within buffer objects used for instanced
	rendering to be specified. This is congruent with the <first> parameter
	in glDrawArrays and the <basevertex> parameter in glDrawElements. When
	instanced rendering is performed (for example, through
	glDrawArraysInstanced), instanced vertex attributes whose vertex attribute
	divisors are non-zero are fetched from enabled vertex arrays per-instance
	rather than per-vertex. However, in unextended OpenGL, there is no way to
	define the offset into those arrays from which the attributes are fetched.
	This extension adds that offset in the form of a <baseinstance> parameter
	to several new procedures.
	
	The <baseinstance> parameter is added to the index of the array element,
	after division by the vertex attribute divisor. This allows several sets of
	instanced vertex attribute data to be stored in a single vertex array, and
	the base offset of that data to be specified for each draw. Further, this
	extension exposes the <baseinstance> parameter as the final and previously
	undefined structure member of the draw-indirect data structure.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/base_instance.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.base_instance import *
from OpenGL.raw.GL.ARB.base_instance import _EXTENSION_NAME

def glInitBaseInstanceARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawElementsInstancedBaseInstance.indices size not checked against count
glDrawElementsInstancedBaseInstance=wrapper.wrapper(glDrawElementsInstancedBaseInstance).setInputArraySize(
    'indices', None
)
# INPUT glDrawElementsInstancedBaseVertexBaseInstance.indices size not checked against count
glDrawElementsInstancedBaseVertexBaseInstance=wrapper.wrapper(glDrawElementsInstancedBaseVertexBaseInstance).setInputArraySize(
    'indices', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_AMD_gpu_association'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_AMD_gpu_association',error_checker=_errors._error_checker)
WGL_GPU_CLOCK_AMD=_C('WGL_GPU_CLOCK_AMD',0x21A4)
WGL_GPU_FASTEST_TARGET_GPUS_AMD=_C('WGL_GPU_FASTEST_TARGET_GPUS_AMD',0x21A2)
WGL_GPU_NUM_PIPES_AMD=_C('WGL_GPU_NUM_PIPES_AMD',0x21A5)
WGL_GPU_NUM_RB_AMD=_C('WGL_GPU_NUM_RB_AMD',0x21A7)
WGL_GPU_NUM_SIMD_AMD=_C('WGL_GPU_NUM_SIMD_AMD',0x21A6)
WGL_GPU_NUM_SPI_AMD=_C('WGL_GPU_NUM_SPI_AMD',0x21A8)
WGL_GPU_OPENGL_VERSION_STRING_AMD=_C('WGL_GPU_OPENGL_VERSION_STRING_AMD',0x1F02)
WGL_GPU_RAM_AMD=_C('WGL_GPU_RAM_AMD',0x21A3)
WGL_GPU_RENDERER_STRING_AMD=_C('WGL_GPU_RENDERER_STRING_AMD',0x1F01)
WGL_GPU_VENDOR_AMD=_C('WGL_GPU_VENDOR_AMD',0x1F00)
@_f
@_p.types(_cs.VOID,_cs.HGLRC,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLbitfield,_cs.GLenum)
def wglBlitContextFramebufferAMD(dstCtx,srcX0,srcY0,srcX1,srcY1,dstX0,dstY0,dstX1,dstY1,mask,filter):pass
@_f
@_p.types(_cs.HGLRC,_cs.UINT)
def wglCreateAssociatedContextAMD(id):pass
@_f
@_p.types(_cs.HGLRC,_cs.UINT,_cs.HGLRC,ctypes.POINTER(_cs.c_int))
def wglCreateAssociatedContextAttribsAMD(id,hShareContext,attribList):pass
@_f
@_p.types(_cs.BOOL,_cs.HGLRC)
def wglDeleteAssociatedContextAMD(hglrc):pass
@_f
@_p.types(_cs.UINT,_cs.HGLRC)
def wglGetContextGPUIDAMD(hglrc):pass
@_f
@_p.types(_cs.HGLRC,)
def wglGetCurrentAssociatedContextAMD():pass
@_f
@_p.types(_cs.UINT,_cs.UINT,ctypes.POINTER(_cs.UINT))
def wglGetGPUIDsAMD(maxCount,ids):pass
@_f
@_p.types(_cs.INT,_cs.UINT,_cs.INT,_cs.GLenum,_cs.UINT,ctypes.c_void_p)
def wglGetGPUInfoAMD(id,property,dataType,size,data):pass
@_f
@_p.types(_cs.BOOL,_cs.HGLRC)
def wglMakeAssociatedContextCurrentAMD(hglrc):pass



'''OpenGL extension VERSION.GL_4_5

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_4_5 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_4_5.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_4_5 import *
from OpenGL.raw.GL.VERSION.GL_4_5 import _EXTENSION_NAME

def glInitGl45VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glCreateTransformFeedbacks.ids size not checked against n
glCreateTransformFeedbacks=wrapper.wrapper(glCreateTransformFeedbacks).setInputArraySize(
    'ids', None
)
# INPUT glCreateBuffers.buffers size not checked against n
glCreateBuffers=wrapper.wrapper(glCreateBuffers).setInputArraySize(
    'buffers', None
)
# INPUT glNamedBufferStorage.data size not checked against size
glNamedBufferStorage=wrapper.wrapper(glNamedBufferStorage).setInputArraySize(
    'data', None
)
# INPUT glNamedBufferSubData.data size not checked against 'size'
glNamedBufferSubData=wrapper.wrapper(glNamedBufferSubData).setInputArraySize(
    'data', None
)
# INPUT glCreateFramebuffers.framebuffers size not checked against n
glCreateFramebuffers=wrapper.wrapper(glCreateFramebuffers).setInputArraySize(
    'framebuffers', None
)
# INPUT glCreateRenderbuffers.renderbuffers size not checked against n
glCreateRenderbuffers=wrapper.wrapper(glCreateRenderbuffers).setInputArraySize(
    'renderbuffers', None
)
# INPUT glCreateTextures.textures size not checked against n
glCreateTextures=wrapper.wrapper(glCreateTextures).setInputArraySize(
    'textures', None
)
# INPUT glCreateVertexArrays.arrays size not checked against n
glCreateVertexArrays=wrapper.wrapper(glCreateVertexArrays).setInputArraySize(
    'arrays', None
)
# INPUT glCreateSamplers.samplers size not checked against n
glCreateSamplers=wrapper.wrapper(glCreateSamplers).setInputArraySize(
    'samplers', None
)
# INPUT glCreateProgramPipelines.pipelines size not checked against n
glCreateProgramPipelines=wrapper.wrapper(glCreateProgramPipelines).setInputArraySize(
    'pipelines', None
)
# INPUT glCreateQueries.ids size not checked against n
glCreateQueries=wrapper.wrapper(glCreateQueries).setInputArraySize(
    'ids', None
)
# INPUT glGetnTexImage.pixels size not checked against bufSize
glGetnTexImage=wrapper.wrapper(glGetnTexImage).setInputArraySize(
    'pixels', None
)
# INPUT glGetnUniformdv.params size not checked against bufSize
glGetnUniformdv=wrapper.wrapper(glGetnUniformdv).setInputArraySize(
    'params', None
)
# INPUT glGetnUniformfv.params size not checked against bufSize
glGetnUniformfv=wrapper.wrapper(glGetnUniformfv).setInputArraySize(
    'params', None
)
# INPUT glGetnUniformiv.params size not checked against bufSize
glGetnUniformiv=wrapper.wrapper(glGetnUniformiv).setInputArraySize(
    'params', None
)
# INPUT glGetnUniformuiv.params size not checked against bufSize
glGetnUniformuiv=wrapper.wrapper(glGetnUniformuiv).setInputArraySize(
    'params', None
)
# INPUT glReadnPixels.data size not checked against bufSize
glReadnPixels=wrapper.wrapper(glReadnPixels).setInputArraySize(
    'data', None
)
### END AUTOGENERATED SECTION



'''OpenGL extension EXT.sRGB_write_control

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.sRGB_write_control to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension's intent is to expose new functionality which allows an
	application the ability to decide if the conversion from linear space to
	sRGB is necessary by enabling or disabling this conversion at framebuffer
	write or blending time. An application which passes non-linear vector data
	to a shader may not want the color conversion occurring, and by disabling
	conversion the application can be simplified, sometimes in very significant
	and more optimal ways.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/sRGB_write_control.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.sRGB_write_control import *
from OpenGL.raw.GLES2.EXT.sRGB_write_control import _EXTENSION_NAME

def glInitSrgbWriteControlEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.read_depth_stencil

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.read_depth_stencil to provide a more 
Python-friendly API

Overview (from the spec)
	
	Unextended OpenGL-ES 2.0 only supports using ReadPixels to read from the
	default color buffer of the currently-bound framebuffer.  However, it is
	useful for debugging to be able to read from depth and stencil buffers.
	This extension re-introduces these features into OpenGL-ES 2.0.
	
	This document describes several extensions in order to allow an
	implementation to support a subset of the total functionality.
	
	The NV_read_depth extension allows reading from the depth buffer using
	ReadPixels.
	
	The NV_read_stencil extension allows reading from the stencil buffer using
	ReadPixels.
	
	The NV_read_depth_stencil extension allows reading from packed
	depth-stencil buffers using ReadPixels.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/read_depth_stencil.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.read_depth_stencil import *
from OpenGL.raw.GLES2.NV.read_depth_stencil import _EXTENSION_NAME

def glInitReadDepthStencilNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.texture_env_crossbar

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.texture_env_crossbar to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds the capability to use the texture color from
	other texture units as sources to the COMBINE enviornment
	function. OpenGL ES 1.1 defined texture combine functions which
	could use the color from the current texture unit as a source. 
	This extension adds the ability to use the color from any texture 
	unit as a source.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/texture_env_crossbar.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.texture_env_crossbar import *
from OpenGL.raw.GLES1.OES.texture_env_crossbar import _EXTENSION_NAME

def glInitTextureEnvCrossbarOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_EXT_context_priority'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_EXT_context_priority',error_checker=_errors._error_checker)
GLX_CONTEXT_PRIORITY_HIGH_EXT=_C('GLX_CONTEXT_PRIORITY_HIGH_EXT',0x3101)
GLX_CONTEXT_PRIORITY_LEVEL_EXT=_C('GLX_CONTEXT_PRIORITY_LEVEL_EXT',0x3100)
GLX_CONTEXT_PRIORITY_LOW_EXT=_C('GLX_CONTEXT_PRIORITY_LOW_EXT',0x3103)
GLX_CONTEXT_PRIORITY_MEDIUM_EXT=_C('GLX_CONTEXT_PRIORITY_MEDIUM_EXT',0x3102)




'''OpenGL extension NV.fragment_coverage_to_color

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.fragment_coverage_to_color to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows the fragment coverage value, represented as an
	integer bitfield, to be substituted for a color output being written to a
	single-component color buffer with integer components (e.g., R8UI).  The
	capability provided by this extension is different from simply writing the
	gl_SampleMask fragment shader output in that the coverage value written to
	the framebuffer is taken after alpha test, stencil test, and depth test,
	as well as after the multisample fragment operations such as
	alpha-to-coverage.
	
	This functionality may be useful for deferred rendering algorithms, where
	the second pass needs to know which samples belong to which original 
	fragments.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/fragment_coverage_to_color.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.fragment_coverage_to_color import *
from OpenGL.raw.GLES2.NV.fragment_coverage_to_color import _EXTENSION_NAME

def glInitFragmentCoverageToColorNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.conditional_render

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.conditional_render to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides support for conditional rendering based on the
	results of an occlusion query.  This mechanism allows an application to
	potentially reduce the latency between the completion of an occlusion
	query and the rendering commands depending on its result.  It additionally
	allows the decision of whether to render to be made without application
	intervention.
	
	This extension defines two new functions, BeginConditionalRenderNV and
	EndConditionalRenderNV, between which rendering commands may be discarded
	based on the results of an occlusion query.  If the specified occlusion
	query returns a non-zero value, rendering commands between these calls are
	executed.  If the occlusion query returns a value of zero, all rendering
	commands between the calls are discarded.
	
	If the occlusion query results are not available when
	BeginConditionalRenderNV is executed, the <mode> parameter specifies
	whether the GL should wait for the query to complete or should simply
	render the subsequent geometry unconditionally.
	
	Additionally, the extension provides a set of "by region" modes, allowing
	for implementations that divide rendering work by screen regions to
	perform the conditional query test on a region-by-region basis without
	checking the query results from other regions.  Such a mode is useful for
	cases like split-frame SLI, where a frame is divided between multiple
	GPUs, each of which has its own occlusion query hardware.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/conditional_render.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.conditional_render import *
from OpenGL.raw.GLES2.NV.conditional_render import _EXTENSION_NAME

def glInitConditionalRenderNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.shader_io_blocks

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.shader_io_blocks to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the functionality of interface blocks to
	support input and output interfaces in the OpenGL ES Shading Language.
	
	Input and output interface blocks are used for forming the
	interfaces between vertex, tessellation control, tessellation
	evaluation, geometry and fragment shaders. This accommodates passing
	arrays between stages, which otherwise would require multi-dimensional
	array support for tessellation control outputs and for tessellation
	control, tessellation evaluation, and geometry shader inputs.
	
	This extension provides support for application defined
	interface blocks which are used for passing application-specific
	information between shader stages.
	
	This extension moves the built-in "per-vertex" in/out variables
	to a new built-in gl_PerVertex block. This is necessary for
	tessellation and geometry shaders which require a separate
	instance for each vertex, but it can also be useful for vertex
	shaders.
	
	Finally, this extension allows the redeclaration of the
	gl_PerVertex block in order to reduce the set of variables that must
	be passed between shaders.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/shader_io_blocks.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.shader_io_blocks import *
from OpenGL.raw.GLES2.EXT.shader_io_blocks import _EXTENSION_NAME

def glInitShaderIoBlocksEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_KHR_debug'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_KHR_debug',error_checker=_errors._error_checker)
GL_BUFFER=_C('GL_BUFFER',0x82E0)
GL_BUFFER_KHR=_C('GL_BUFFER_KHR',0x82E0)
GL_CONTEXT_FLAG_DEBUG_BIT=_C('GL_CONTEXT_FLAG_DEBUG_BIT',0x00000002)
GL_CONTEXT_FLAG_DEBUG_BIT_KHR=_C('GL_CONTEXT_FLAG_DEBUG_BIT_KHR',0x00000002)
GL_DEBUG_CALLBACK_FUNCTION=_C('GL_DEBUG_CALLBACK_FUNCTION',0x8244)
GL_DEBUG_CALLBACK_FUNCTION_KHR=_C('GL_DEBUG_CALLBACK_FUNCTION_KHR',0x8244)
GL_DEBUG_CALLBACK_USER_PARAM=_C('GL_DEBUG_CALLBACK_USER_PARAM',0x8245)
GL_DEBUG_CALLBACK_USER_PARAM_KHR=_C('GL_DEBUG_CALLBACK_USER_PARAM_KHR',0x8245)
GL_DEBUG_GROUP_STACK_DEPTH=_C('GL_DEBUG_GROUP_STACK_DEPTH',0x826D)
GL_DEBUG_GROUP_STACK_DEPTH_KHR=_C('GL_DEBUG_GROUP_STACK_DEPTH_KHR',0x826D)
GL_DEBUG_LOGGED_MESSAGES=_C('GL_DEBUG_LOGGED_MESSAGES',0x9145)
GL_DEBUG_LOGGED_MESSAGES_KHR=_C('GL_DEBUG_LOGGED_MESSAGES_KHR',0x9145)
GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH=_C('GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH',0x8243)
GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_KHR=_C('GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_KHR',0x8243)
GL_DEBUG_OUTPUT=_C('GL_DEBUG_OUTPUT',0x92E0)
GL_DEBUG_OUTPUT_KHR=_C('GL_DEBUG_OUTPUT_KHR',0x92E0)
GL_DEBUG_OUTPUT_SYNCHRONOUS=_C('GL_DEBUG_OUTPUT_SYNCHRONOUS',0x8242)
GL_DEBUG_OUTPUT_SYNCHRONOUS_KHR=_C('GL_DEBUG_OUTPUT_SYNCHRONOUS_KHR',0x8242)
GL_DEBUG_SEVERITY_HIGH=_C('GL_DEBUG_SEVERITY_HIGH',0x9146)
GL_DEBUG_SEVERITY_HIGH_KHR=_C('GL_DEBUG_SEVERITY_HIGH_KHR',0x9146)
GL_DEBUG_SEVERITY_LOW=_C('GL_DEBUG_SEVERITY_LOW',0x9148)
GL_DEBUG_SEVERITY_LOW_KHR=_C('GL_DEBUG_SEVERITY_LOW_KHR',0x9148)
GL_DEBUG_SEVERITY_MEDIUM=_C('GL_DEBUG_SEVERITY_MEDIUM',0x9147)
GL_DEBUG_SEVERITY_MEDIUM_KHR=_C('GL_DEBUG_SEVERITY_MEDIUM_KHR',0x9147)
GL_DEBUG_SEVERITY_NOTIFICATION=_C('GL_DEBUG_SEVERITY_NOTIFICATION',0x826B)
GL_DEBUG_SEVERITY_NOTIFICATION_KHR=_C('GL_DEBUG_SEVERITY_NOTIFICATION_KHR',0x826B)
GL_DEBUG_SOURCE_API=_C('GL_DEBUG_SOURCE_API',0x8246)
GL_DEBUG_SOURCE_API_KHR=_C('GL_DEBUG_SOURCE_API_KHR',0x8246)
GL_DEBUG_SOURCE_APPLICATION=_C('GL_DEBUG_SOURCE_APPLICATION',0x824A)
GL_DEBUG_SOURCE_APPLICATION_KHR=_C('GL_DEBUG_SOURCE_APPLICATION_KHR',0x824A)
GL_DEBUG_SOURCE_OTHER=_C('GL_DEBUG_SOURCE_OTHER',0x824B)
GL_DEBUG_SOURCE_OTHER_KHR=_C('GL_DEBUG_SOURCE_OTHER_KHR',0x824B)
GL_DEBUG_SOURCE_SHADER_COMPILER=_C('GL_DEBUG_SOURCE_SHADER_COMPILER',0x8248)
GL_DEBUG_SOURCE_SHADER_COMPILER_KHR=_C('GL_DEBUG_SOURCE_SHADER_COMPILER_KHR',0x8248)
GL_DEBUG_SOURCE_THIRD_PARTY=_C('GL_DEBUG_SOURCE_THIRD_PARTY',0x8249)
GL_DEBUG_SOURCE_THIRD_PARTY_KHR=_C('GL_DEBUG_SOURCE_THIRD_PARTY_KHR',0x8249)
GL_DEBUG_SOURCE_WINDOW_SYSTEM=_C('GL_DEBUG_SOURCE_WINDOW_SYSTEM',0x8247)
GL_DEBUG_SOURCE_WINDOW_SYSTEM_KHR=_C('GL_DEBUG_SOURCE_WINDOW_SYSTEM_KHR',0x8247)
GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR=_C('GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR',0x824D)
GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR_KHR=_C('GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR_KHR',0x824D)
GL_DEBUG_TYPE_ERROR=_C('GL_DEBUG_TYPE_ERROR',0x824C)
GL_DEBUG_TYPE_ERROR_KHR=_C('GL_DEBUG_TYPE_ERROR_KHR',0x824C)
GL_DEBUG_TYPE_MARKER=_C('GL_DEBUG_TYPE_MARKER',0x8268)
GL_DEBUG_TYPE_MARKER_KHR=_C('GL_DEBUG_TYPE_MARKER_KHR',0x8268)
GL_DEBUG_TYPE_OTHER=_C('GL_DEBUG_TYPE_OTHER',0x8251)
GL_DEBUG_TYPE_OTHER_KHR=_C('GL_DEBUG_TYPE_OTHER_KHR',0x8251)
GL_DEBUG_TYPE_PERFORMANCE=_C('GL_DEBUG_TYPE_PERFORMANCE',0x8250)
GL_DEBUG_TYPE_PERFORMANCE_KHR=_C('GL_DEBUG_TYPE_PERFORMANCE_KHR',0x8250)
GL_DEBUG_TYPE_POP_GROUP=_C('GL_DEBUG_TYPE_POP_GROUP',0x826A)
GL_DEBUG_TYPE_POP_GROUP_KHR=_C('GL_DEBUG_TYPE_POP_GROUP_KHR',0x826A)
GL_DEBUG_TYPE_PORTABILITY=_C('GL_DEBUG_TYPE_PORTABILITY',0x824F)
GL_DEBUG_TYPE_PORTABILITY_KHR=_C('GL_DEBUG_TYPE_PORTABILITY_KHR',0x824F)
GL_DEBUG_TYPE_PUSH_GROUP=_C('GL_DEBUG_TYPE_PUSH_GROUP',0x8269)
GL_DEBUG_TYPE_PUSH_GROUP_KHR=_C('GL_DEBUG_TYPE_PUSH_GROUP_KHR',0x8269)
GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR=_C('GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR',0x824E)
GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR_KHR=_C('GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR_KHR',0x824E)
GL_DISPLAY_LIST=_C('GL_DISPLAY_LIST',0x82E7)
GL_MAX_DEBUG_GROUP_STACK_DEPTH=_C('GL_MAX_DEBUG_GROUP_STACK_DEPTH',0x826C)
GL_MAX_DEBUG_GROUP_STACK_DEPTH_KHR=_C('GL_MAX_DEBUG_GROUP_STACK_DEPTH_KHR',0x826C)
GL_MAX_DEBUG_LOGGED_MESSAGES=_C('GL_MAX_DEBUG_LOGGED_MESSAGES',0x9144)
GL_MAX_DEBUG_LOGGED_MESSAGES_KHR=_C('GL_MAX_DEBUG_LOGGED_MESSAGES_KHR',0x9144)
GL_MAX_DEBUG_MESSAGE_LENGTH=_C('GL_MAX_DEBUG_MESSAGE_LENGTH',0x9143)
GL_MAX_DEBUG_MESSAGE_LENGTH_KHR=_C('GL_MAX_DEBUG_MESSAGE_LENGTH_KHR',0x9143)
GL_MAX_LABEL_LENGTH=_C('GL_MAX_LABEL_LENGTH',0x82E8)
GL_MAX_LABEL_LENGTH_KHR=_C('GL_MAX_LABEL_LENGTH_KHR',0x82E8)
GL_PROGRAM=_C('GL_PROGRAM',0x82E2)
GL_PROGRAM_KHR=_C('GL_PROGRAM_KHR',0x82E2)
GL_PROGRAM_PIPELINE=_C('GL_PROGRAM_PIPELINE',0x82E4)
GL_PROGRAM_PIPELINE_KHR=_C('GL_PROGRAM_PIPELINE_KHR',0x82E4)
GL_QUERY=_C('GL_QUERY',0x82E3)
GL_QUERY_KHR=_C('GL_QUERY_KHR',0x82E3)
GL_SAMPLER=_C('GL_SAMPLER',0x82E6)
GL_SAMPLER_KHR=_C('GL_SAMPLER_KHR',0x82E6)
GL_SHADER=_C('GL_SHADER',0x82E1)
GL_SHADER_KHR=_C('GL_SHADER_KHR',0x82E1)
GL_STACK_OVERFLOW=_C('GL_STACK_OVERFLOW',0x0503)
GL_STACK_OVERFLOW_KHR=_C('GL_STACK_OVERFLOW_KHR',0x0503)
GL_STACK_UNDERFLOW=_C('GL_STACK_UNDERFLOW',0x0504)
GL_STACK_UNDERFLOW_KHR=_C('GL_STACK_UNDERFLOW_KHR',0x0504)
GL_VERTEX_ARRAY=_C('GL_VERTEX_ARRAY',0x8074)
GL_VERTEX_ARRAY_KHR=_C('GL_VERTEX_ARRAY_KHR',0x8074)
@_f
@_p.types(None,_cs.GLDEBUGPROC,ctypes.c_void_p)
def glDebugMessageCallback(callback,userParam):pass
@_f
@_p.types(None,_cs.GLDEBUGPROCKHR,ctypes.c_void_p)
def glDebugMessageCallbackKHR(callback,userParam):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray,_cs.GLboolean)
def glDebugMessageControl(source,type,severity,count,ids,enabled):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray,_cs.GLboolean)
def glDebugMessageControlKHR(source,type,severity,count,ids,enabled):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLsizei,arrays.GLcharArray)
def glDebugMessageInsert(source,type,id,severity,length,buf):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLenum,_cs.GLsizei,arrays.GLcharArray)
def glDebugMessageInsertKHR(source,type,id,severity,length,buf):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetDebugMessageLog(count,bufSize,sources,types,ids,severities,lengths,messageLog):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLuintArray,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetDebugMessageLogKHR(count,bufSize,sources,types,ids,severities,lengths,messageLog):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetObjectLabel(identifier,name,bufSize,length,label):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetObjectLabelKHR(identifier,name,bufSize,length,label):pass
@_f
@_p.types(None,ctypes.c_void_p,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetObjectPtrLabel(ptr,bufSize,length,label):pass
@_f
@_p.types(None,ctypes.c_void_p,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetObjectPtrLabelKHR(ptr,bufSize,length,label):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLvoidpArray)
def glGetPointerv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLvoidpArray)
def glGetPointervKHR(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLcharArray)
def glObjectLabel(identifier,name,length,label):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLcharArray)
def glObjectLabelKHR(identifier,name,length,label):pass
@_f
@_p.types(None,ctypes.c_void_p,_cs.GLsizei,arrays.GLcharArray)
def glObjectPtrLabel(ptr,length,label):pass
@_f
@_p.types(None,ctypes.c_void_p,_cs.GLsizei,arrays.GLcharArray)
def glObjectPtrLabelKHR(ptr,length,label):pass
@_f
@_p.types(None,)
def glPopDebugGroup():pass
@_f
@_p.types(None,)
def glPopDebugGroupKHR():pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLcharArray)
def glPushDebugGroup(source,id,length,message):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLcharArray)
def glPushDebugGroupKHR(source,id,length,message):pass



'''OpenGL extension INTEL.map_texture

This module customises the behaviour of the 
OpenGL.raw.GL.INTEL.map_texture to provide a more 
Python-friendly API

Overview (from the spec)
	Systems with integrated GPUs can share the same physical memory between CPU
	and GPU. This feature, if exposed by API, can bring significant performance
	benefits for graphics applications by reducing the complexity of
	uploading/accessing texture contents. This extension enables CPU direct
	access to the GPU memory holding textures.
	
	The problem with texture memory directly exposed to clients is that
	textures are often 'tiled'. Texels are kept in specific layout to improve
	locality of reference and thus performance of texturing. This 'tiling'
	is specific to particular hardware and would be thus difficult to use.
	
	This extension allows to create textures with 'linear' layout which allows
	for simplified access on user side (potentially sacrificing some
	performance during texture sampling).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/INTEL/map_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.INTEL.map_texture import *
from OpenGL.raw.GL.INTEL.map_texture import _EXTENSION_NAME

def glInitMapTextureINTEL():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glMapTexture2DINTEL=wrapper.wrapper(glMapTexture2DINTEL).setInputArraySize(
    'layout', 1
).setInputArraySize(
    'stride', 1
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_IMG_bindless_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_IMG_bindless_texture',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.GLuint64,_cs.GLuint)
def glGetTextureHandleIMG(texture):pass
@_f
@_p.types(_cs.GLuint64,_cs.GLuint,_cs.GLuint)
def glGetTextureSamplerHandleIMG(texture,sampler):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLuint64)
def glProgramUniformHandleui64IMG(program,location,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuint64Array)
def glProgramUniformHandleui64vIMG(program,location,count,values):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint64)
def glUniformHandleui64IMG(location,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuint64Array)
def glUniformHandleui64vIMG(location,count,value):pass



'''OpenGL extension ARM.shader_framebuffer_fetch

This module customises the behaviour of the 
OpenGL.raw.GLES2.ARM.shader_framebuffer_fetch to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension enables fragment shaders to read existing framebuffer
	data as input. This permits use-cases such as programmable blending,
	and other operations that may not be possible to implement with
	fixed-function blending.
	
	This extension also adds the ability to indicate that a shader should
	be run once per sample instead of once per pixel.
	
	Reading framebuffer data as input in combination with multiple render
	targets (MRT) may not be supported by all implementations. This
	extension allows applications to query for this capability.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARM/shader_framebuffer_fetch.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.ARM.shader_framebuffer_fetch import *
from OpenGL.raw.GLES2.ARM.shader_framebuffer_fetch import _EXTENSION_NAME

def glInitShaderFramebufferFetchARM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES3 import _types as _cs
# End users want this...
from OpenGL.raw.GLES3._types import *
from OpenGL.raw.GLES3 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES3_VERSION_GLES3_3_0'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES3,'GLES3_VERSION_GLES3_3_0',error_checker=_errors._error_checker)
GL_ACTIVE_UNIFORM_BLOCKS=_C('GL_ACTIVE_UNIFORM_BLOCKS',0x8A36)
GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH=_C('GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH',0x8A35)
GL_ALREADY_SIGNALED=_C('GL_ALREADY_SIGNALED',0x911A)
GL_ANY_SAMPLES_PASSED=_C('GL_ANY_SAMPLES_PASSED',0x8C2F)
GL_ANY_SAMPLES_PASSED_CONSERVATIVE=_C('GL_ANY_SAMPLES_PASSED_CONSERVATIVE',0x8D6A)
GL_BLUE=_C('GL_BLUE',0x1905)
GL_BUFFER_ACCESS_FLAGS=_C('GL_BUFFER_ACCESS_FLAGS',0x911F)
GL_BUFFER_MAPPED=_C('GL_BUFFER_MAPPED',0x88BC)
GL_BUFFER_MAP_LENGTH=_C('GL_BUFFER_MAP_LENGTH',0x9120)
GL_BUFFER_MAP_OFFSET=_C('GL_BUFFER_MAP_OFFSET',0x9121)
GL_BUFFER_MAP_POINTER=_C('GL_BUFFER_MAP_POINTER',0x88BD)
GL_COLOR=_C('GL_COLOR',0x1800)
GL_COLOR_ATTACHMENT1=_C('GL_COLOR_ATTACHMENT1',0x8CE1)
GL_COLOR_ATTACHMENT10=_C('GL_COLOR_ATTACHMENT10',0x8CEA)
GL_COLOR_ATTACHMENT11=_C('GL_COLOR_ATTACHMENT11',0x8CEB)
GL_COLOR_ATTACHMENT12=_C('GL_COLOR_ATTACHMENT12',0x8CEC)
GL_COLOR_ATTACHMENT13=_C('GL_COLOR_ATTACHMENT13',0x8CED)
GL_COLOR_ATTACHMENT14=_C('GL_COLOR_ATTACHMENT14',0x8CEE)
GL_COLOR_ATTACHMENT15=_C('GL_COLOR_ATTACHMENT15',0x8CEF)
GL_COLOR_ATTACHMENT16=_C('GL_COLOR_ATTACHMENT16',0x8CF0)
GL_COLOR_ATTACHMENT17=_C('GL_COLOR_ATTACHMENT17',0x8CF1)
GL_COLOR_ATTACHMENT18=_C('GL_COLOR_ATTACHMENT18',0x8CF2)
GL_COLOR_ATTACHMENT19=_C('GL_COLOR_ATTACHMENT19',0x8CF3)
GL_COLOR_ATTACHMENT2=_C('GL_COLOR_ATTACHMENT2',0x8CE2)
GL_COLOR_ATTACHMENT20=_C('GL_COLOR_ATTACHMENT20',0x8CF4)
GL_COLOR_ATTACHMENT21=_C('GL_COLOR_ATTACHMENT21',0x8CF5)
GL_COLOR_ATTACHMENT22=_C('GL_COLOR_ATTACHMENT22',0x8CF6)
GL_COLOR_ATTACHMENT23=_C('GL_COLOR_ATTACHMENT23',0x8CF7)
GL_COLOR_ATTACHMENT24=_C('GL_COLOR_ATTACHMENT24',0x8CF8)
GL_COLOR_ATTACHMENT25=_C('GL_COLOR_ATTACHMENT25',0x8CF9)
GL_COLOR_ATTACHMENT26=_C('GL_COLOR_ATTACHMENT26',0x8CFA)
GL_COLOR_ATTACHMENT27=_C('GL_COLOR_ATTACHMENT27',0x8CFB)
GL_COLOR_ATTACHMENT28=_C('GL_COLOR_ATTACHMENT28',0x8CFC)
GL_COLOR_ATTACHMENT29=_C('GL_COLOR_ATTACHMENT29',0x8CFD)
GL_COLOR_ATTACHMENT3=_C('GL_COLOR_ATTACHMENT3',0x8CE3)
GL_COLOR_ATTACHMENT30=_C('GL_COLOR_ATTACHMENT30',0x8CFE)
GL_COLOR_ATTACHMENT31=_C('GL_COLOR_ATTACHMENT31',0x8CFF)
GL_COLOR_ATTACHMENT4=_C('GL_COLOR_ATTACHMENT4',0x8CE4)
GL_COLOR_ATTACHMENT5=_C('GL_COLOR_ATTACHMENT5',0x8CE5)
GL_COLOR_ATTACHMENT6=_C('GL_COLOR_ATTACHMENT6',0x8CE6)
GL_COLOR_ATTACHMENT7=_C('GL_COLOR_ATTACHMENT7',0x8CE7)
GL_COLOR_ATTACHMENT8=_C('GL_COLOR_ATTACHMENT8',0x8CE8)
GL_COLOR_ATTACHMENT9=_C('GL_COLOR_ATTACHMENT9',0x8CE9)
GL_COMPARE_REF_TO_TEXTURE=_C('GL_COMPARE_REF_TO_TEXTURE',0x884E)
GL_COMPRESSED_R11_EAC=_C('GL_COMPRESSED_R11_EAC',0x9270)
GL_COMPRESSED_RG11_EAC=_C('GL_COMPRESSED_RG11_EAC',0x9272)
GL_COMPRESSED_RGB8_ETC2=_C('GL_COMPRESSED_RGB8_ETC2',0x9274)
GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2=_C('GL_COMPRESSED_RGB8_PUNCHTHROUGH_ALPHA1_ETC2',0x9276)
GL_COMPRESSED_RGBA8_ETC2_EAC=_C('GL_COMPRESSED_RGBA8_ETC2_EAC',0x9278)
GL_COMPRESSED_SIGNED_R11_EAC=_C('GL_COMPRESSED_SIGNED_R11_EAC',0x9271)
GL_COMPRESSED_SIGNED_RG11_EAC=_C('GL_COMPRESSED_SIGNED_RG11_EAC',0x9273)
GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC=_C('GL_COMPRESSED_SRGB8_ALPHA8_ETC2_EAC',0x9279)
GL_COMPRESSED_SRGB8_ETC2=_C('GL_COMPRESSED_SRGB8_ETC2',0x9275)
GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2=_C('GL_COMPRESSED_SRGB8_PUNCHTHROUGH_ALPHA1_ETC2',0x9277)
GL_CONDITION_SATISFIED=_C('GL_CONDITION_SATISFIED',0x911C)
GL_COPY_READ_BUFFER=_C('GL_COPY_READ_BUFFER',0x8F36)
GL_COPY_READ_BUFFER_BINDING=_C('GL_COPY_READ_BUFFER_BINDING',0x8F36)
GL_COPY_WRITE_BUFFER=_C('GL_COPY_WRITE_BUFFER',0x8F37)
GL_COPY_WRITE_BUFFER_BINDING=_C('GL_COPY_WRITE_BUFFER_BINDING',0x8F37)
GL_CURRENT_QUERY=_C('GL_CURRENT_QUERY',0x8865)
GL_DEPTH=_C('GL_DEPTH',0x1801)
GL_DEPTH24_STENCIL8=_C('GL_DEPTH24_STENCIL8',0x88F0)
GL_DEPTH32F_STENCIL8=_C('GL_DEPTH32F_STENCIL8',0x8CAD)
GL_DEPTH_COMPONENT24=_C('GL_DEPTH_COMPONENT24',0x81A6)
GL_DEPTH_COMPONENT32F=_C('GL_DEPTH_COMPONENT32F',0x8CAC)
GL_DEPTH_STENCIL=_C('GL_DEPTH_STENCIL',0x84F9)
GL_DEPTH_STENCIL_ATTACHMENT=_C('GL_DEPTH_STENCIL_ATTACHMENT',0x821A)
GL_DRAW_BUFFER0=_C('GL_DRAW_BUFFER0',0x8825)
GL_DRAW_BUFFER1=_C('GL_DRAW_BUFFER1',0x8826)
GL_DRAW_BUFFER10=_C('GL_DRAW_BUFFER10',0x882F)
GL_DRAW_BUFFER11=_C('GL_DRAW_BUFFER11',0x8830)
GL_DRAW_BUFFER12=_C('GL_DRAW_BUFFER12',0x8831)
GL_DRAW_BUFFER13=_C('GL_DRAW_BUFFER13',0x8832)
GL_DRAW_BUFFER14=_C('GL_DRAW_BUFFER14',0x8833)
GL_DRAW_BUFFER15=_C('GL_DRAW_BUFFER15',0x8834)
GL_DRAW_BUFFER2=_C('GL_DRAW_BUFFER2',0x8827)
GL_DRAW_BUFFER3=_C('GL_DRAW_BUFFER3',0x8828)
GL_DRAW_BUFFER4=_C('GL_DRAW_BUFFER4',0x8829)
GL_DRAW_BUFFER5=_C('GL_DRAW_BUFFER5',0x882A)
GL_DRAW_BUFFER6=_C('GL_DRAW_BUFFER6',0x882B)
GL_DRAW_BUFFER7=_C('GL_DRAW_BUFFER7',0x882C)
GL_DRAW_BUFFER8=_C('GL_DRAW_BUFFER8',0x882D)
GL_DRAW_BUFFER9=_C('GL_DRAW_BUFFER9',0x882E)
GL_DRAW_FRAMEBUFFER=_C('GL_DRAW_FRAMEBUFFER',0x8CA9)
GL_DRAW_FRAMEBUFFER_BINDING=_C('GL_DRAW_FRAMEBUFFER_BINDING',0x8CA6)
GL_DYNAMIC_COPY=_C('GL_DYNAMIC_COPY',0x88EA)
GL_DYNAMIC_READ=_C('GL_DYNAMIC_READ',0x88E9)
GL_FLOAT_32_UNSIGNED_INT_24_8_REV=_C('GL_FLOAT_32_UNSIGNED_INT_24_8_REV',0x8DAD)
GL_FLOAT_MAT2x3=_C('GL_FLOAT_MAT2x3',0x8B65)
GL_FLOAT_MAT2x4=_C('GL_FLOAT_MAT2x4',0x8B66)
GL_FLOAT_MAT3x2=_C('GL_FLOAT_MAT3x2',0x8B67)
GL_FLOAT_MAT3x4=_C('GL_FLOAT_MAT3x4',0x8B68)
GL_FLOAT_MAT4x2=_C('GL_FLOAT_MAT4x2',0x8B69)
GL_FLOAT_MAT4x3=_C('GL_FLOAT_MAT4x3',0x8B6A)
GL_FRAGMENT_SHADER_DERIVATIVE_HINT=_C('GL_FRAGMENT_SHADER_DERIVATIVE_HINT',0x8B8B)
GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE',0x8215)
GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE',0x8214)
GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING=_C('GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING',0x8210)
GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE=_C('GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE',0x8211)
GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE',0x8216)
GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE',0x8213)
GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE',0x8212)
GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE',0x8217)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER',0x8CD4)
GL_FRAMEBUFFER_DEFAULT=_C('GL_FRAMEBUFFER_DEFAULT',0x8218)
GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE=_C('GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE',0x8D56)
GL_FRAMEBUFFER_UNDEFINED=_C('GL_FRAMEBUFFER_UNDEFINED',0x8219)
GL_GREEN=_C('GL_GREEN',0x1904)
GL_HALF_FLOAT=_C('GL_HALF_FLOAT',0x140B)
GL_INTERLEAVED_ATTRIBS=_C('GL_INTERLEAVED_ATTRIBS',0x8C8C)
GL_INT_2_10_10_10_REV=_C('GL_INT_2_10_10_10_REV',0x8D9F)
GL_INT_SAMPLER_2D=_C('GL_INT_SAMPLER_2D',0x8DCA)
GL_INT_SAMPLER_2D_ARRAY=_C('GL_INT_SAMPLER_2D_ARRAY',0x8DCF)
GL_INT_SAMPLER_3D=_C('GL_INT_SAMPLER_3D',0x8DCB)
GL_INT_SAMPLER_CUBE=_C('GL_INT_SAMPLER_CUBE',0x8DCC)
GL_INVALID_INDEX=_C('GL_INVALID_INDEX',0xFFFFFFFF)
GL_MAJOR_VERSION=_C('GL_MAJOR_VERSION',0x821B)
GL_MAP_FLUSH_EXPLICIT_BIT=_C('GL_MAP_FLUSH_EXPLICIT_BIT',0x0010)
GL_MAP_INVALIDATE_BUFFER_BIT=_C('GL_MAP_INVALIDATE_BUFFER_BIT',0x0008)
GL_MAP_INVALIDATE_RANGE_BIT=_C('GL_MAP_INVALIDATE_RANGE_BIT',0x0004)
GL_MAP_READ_BIT=_C('GL_MAP_READ_BIT',0x0001)
GL_MAP_UNSYNCHRONIZED_BIT=_C('GL_MAP_UNSYNCHRONIZED_BIT',0x0020)
GL_MAP_WRITE_BIT=_C('GL_MAP_WRITE_BIT',0x0002)
GL_MAX=_C('GL_MAX',0x8008)
GL_MAX_3D_TEXTURE_SIZE=_C('GL_MAX_3D_TEXTURE_SIZE',0x8073)
GL_MAX_ARRAY_TEXTURE_LAYERS=_C('GL_MAX_ARRAY_TEXTURE_LAYERS',0x88FF)
GL_MAX_COLOR_ATTACHMENTS=_C('GL_MAX_COLOR_ATTACHMENTS',0x8CDF)
GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS=_C('GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS',0x8A33)
GL_MAX_COMBINED_UNIFORM_BLOCKS=_C('GL_MAX_COMBINED_UNIFORM_BLOCKS',0x8A2E)
GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS=_C('GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS',0x8A31)
GL_MAX_DRAW_BUFFERS=_C('GL_MAX_DRAW_BUFFERS',0x8824)
GL_MAX_ELEMENTS_INDICES=_C('GL_MAX_ELEMENTS_INDICES',0x80E9)
GL_MAX_ELEMENTS_VERTICES=_C('GL_MAX_ELEMENTS_VERTICES',0x80E8)
GL_MAX_ELEMENT_INDEX=_C('GL_MAX_ELEMENT_INDEX',0x8D6B)
GL_MAX_FRAGMENT_INPUT_COMPONENTS=_C('GL_MAX_FRAGMENT_INPUT_COMPONENTS',0x9125)
GL_MAX_FRAGMENT_UNIFORM_BLOCKS=_C('GL_MAX_FRAGMENT_UNIFORM_BLOCKS',0x8A2D)
GL_MAX_FRAGMENT_UNIFORM_COMPONENTS=_C('GL_MAX_FRAGMENT_UNIFORM_COMPONENTS',0x8B49)
GL_MAX_PROGRAM_TEXEL_OFFSET=_C('GL_MAX_PROGRAM_TEXEL_OFFSET',0x8905)
GL_MAX_SAMPLES=_C('GL_MAX_SAMPLES',0x8D57)
GL_MAX_SERVER_WAIT_TIMEOUT=_C('GL_MAX_SERVER_WAIT_TIMEOUT',0x9111)
GL_MAX_TEXTURE_LOD_BIAS=_C('GL_MAX_TEXTURE_LOD_BIAS',0x84FD)
GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS=_C('GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS',0x8C8A)
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS=_C('GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS',0x8C8B)
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS=_C('GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS',0x8C80)
GL_MAX_UNIFORM_BLOCK_SIZE=_C('GL_MAX_UNIFORM_BLOCK_SIZE',0x8A30)
GL_MAX_UNIFORM_BUFFER_BINDINGS=_C('GL_MAX_UNIFORM_BUFFER_BINDINGS',0x8A2F)
GL_MAX_VARYING_COMPONENTS=_C('GL_MAX_VARYING_COMPONENTS',0x8B4B)
GL_MAX_VERTEX_OUTPUT_COMPONENTS=_C('GL_MAX_VERTEX_OUTPUT_COMPONENTS',0x9122)
GL_MAX_VERTEX_UNIFORM_BLOCKS=_C('GL_MAX_VERTEX_UNIFORM_BLOCKS',0x8A2B)
GL_MAX_VERTEX_UNIFORM_COMPONENTS=_C('GL_MAX_VERTEX_UNIFORM_COMPONENTS',0x8B4A)
GL_MIN=_C('GL_MIN',0x8007)
GL_MINOR_VERSION=_C('GL_MINOR_VERSION',0x821C)
GL_MIN_PROGRAM_TEXEL_OFFSET=_C('GL_MIN_PROGRAM_TEXEL_OFFSET',0x8904)
GL_NUM_EXTENSIONS=_C('GL_NUM_EXTENSIONS',0x821D)
GL_NUM_PROGRAM_BINARY_FORMATS=_C('GL_NUM_PROGRAM_BINARY_FORMATS',0x87FE)
GL_NUM_SAMPLE_COUNTS=_C('GL_NUM_SAMPLE_COUNTS',0x9380)
GL_OBJECT_TYPE=_C('GL_OBJECT_TYPE',0x9112)
GL_PACK_ROW_LENGTH=_C('GL_PACK_ROW_LENGTH',0x0D02)
GL_PACK_SKIP_PIXELS=_C('GL_PACK_SKIP_PIXELS',0x0D04)
GL_PACK_SKIP_ROWS=_C('GL_PACK_SKIP_ROWS',0x0D03)
GL_PIXEL_PACK_BUFFER=_C('GL_PIXEL_PACK_BUFFER',0x88EB)
GL_PIXEL_PACK_BUFFER_BINDING=_C('GL_PIXEL_PACK_BUFFER_BINDING',0x88ED)
GL_PIXEL_UNPACK_BUFFER=_C('GL_PIXEL_UNPACK_BUFFER',0x88EC)
GL_PIXEL_UNPACK_BUFFER_BINDING=_C('GL_PIXEL_UNPACK_BUFFER_BINDING',0x88EF)
GL_PRIMITIVE_RESTART_FIXED_INDEX=_C('GL_PRIMITIVE_RESTART_FIXED_INDEX',0x8D69)
GL_PROGRAM_BINARY_FORMATS=_C('GL_PROGRAM_BINARY_FORMATS',0x87FF)
GL_PROGRAM_BINARY_LENGTH=_C('GL_PROGRAM_BINARY_LENGTH',0x8741)
GL_PROGRAM_BINARY_RETRIEVABLE_HINT=_C('GL_PROGRAM_BINARY_RETRIEVABLE_HINT',0x8257)
GL_QUERY_RESULT=_C('GL_QUERY_RESULT',0x8866)
GL_QUERY_RESULT_AVAILABLE=_C('GL_QUERY_RESULT_AVAILABLE',0x8867)
GL_R11F_G11F_B10F=_C('GL_R11F_G11F_B10F',0x8C3A)
GL_R16F=_C('GL_R16F',0x822D)
GL_R16I=_C('GL_R16I',0x8233)
GL_R16UI=_C('GL_R16UI',0x8234)
GL_R32F=_C('GL_R32F',0x822E)
GL_R32I=_C('GL_R32I',0x8235)
GL_R32UI=_C('GL_R32UI',0x8236)
GL_R8=_C('GL_R8',0x8229)
GL_R8I=_C('GL_R8I',0x8231)
GL_R8UI=_C('GL_R8UI',0x8232)
GL_R8_SNORM=_C('GL_R8_SNORM',0x8F94)
GL_RASTERIZER_DISCARD=_C('GL_RASTERIZER_DISCARD',0x8C89)
GL_READ_BUFFER=_C('GL_READ_BUFFER',0x0C02)
GL_READ_FRAMEBUFFER=_C('GL_READ_FRAMEBUFFER',0x8CA8)
GL_READ_FRAMEBUFFER_BINDING=_C('GL_READ_FRAMEBUFFER_BINDING',0x8CAA)
GL_RED=_C('GL_RED',0x1903)
GL_RED_INTEGER=_C('GL_RED_INTEGER',0x8D94)
GL_RENDERBUFFER_SAMPLES=_C('GL_RENDERBUFFER_SAMPLES',0x8CAB)
GL_RG=_C('GL_RG',0x8227)
GL_RG16F=_C('GL_RG16F',0x822F)
GL_RG16I=_C('GL_RG16I',0x8239)
GL_RG16UI=_C('GL_RG16UI',0x823A)
GL_RG32F=_C('GL_RG32F',0x8230)
GL_RG32I=_C('GL_RG32I',0x823B)
GL_RG32UI=_C('GL_RG32UI',0x823C)
GL_RG8=_C('GL_RG8',0x822B)
GL_RG8I=_C('GL_RG8I',0x8237)
GL_RG8UI=_C('GL_RG8UI',0x8238)
GL_RG8_SNORM=_C('GL_RG8_SNORM',0x8F95)
GL_RGB10_A2=_C('GL_RGB10_A2',0x8059)
GL_RGB10_A2UI=_C('GL_RGB10_A2UI',0x906F)
GL_RGB16F=_C('GL_RGB16F',0x881B)
GL_RGB16I=_C('GL_RGB16I',0x8D89)
GL_RGB16UI=_C('GL_RGB16UI',0x8D77)
GL_RGB32F=_C('GL_RGB32F',0x8815)
GL_RGB32I=_C('GL_RGB32I',0x8D83)
GL_RGB32UI=_C('GL_RGB32UI',0x8D71)
GL_RGB8=_C('GL_RGB8',0x8051)
GL_RGB8I=_C('GL_RGB8I',0x8D8F)
GL_RGB8UI=_C('GL_RGB8UI',0x8D7D)
GL_RGB8_SNORM=_C('GL_RGB8_SNORM',0x8F96)
GL_RGB9_E5=_C('GL_RGB9_E5',0x8C3D)
GL_RGBA16F=_C('GL_RGBA16F',0x881A)
GL_RGBA16I=_C('GL_RGBA16I',0x8D88)
GL_RGBA16UI=_C('GL_RGBA16UI',0x8D76)
GL_RGBA32F=_C('GL_RGBA32F',0x8814)
GL_RGBA32I=_C('GL_RGBA32I',0x8D82)
GL_RGBA32UI=_C('GL_RGBA32UI',0x8D70)
GL_RGBA8=_C('GL_RGBA8',0x8058)
GL_RGBA8I=_C('GL_RGBA8I',0x8D8E)
GL_RGBA8UI=_C('GL_RGBA8UI',0x8D7C)
GL_RGBA8_SNORM=_C('GL_RGBA8_SNORM',0x8F97)
GL_RGBA_INTEGER=_C('GL_RGBA_INTEGER',0x8D99)
GL_RGB_INTEGER=_C('GL_RGB_INTEGER',0x8D98)
GL_RG_INTEGER=_C('GL_RG_INTEGER',0x8228)
GL_SAMPLER_2D_ARRAY=_C('GL_SAMPLER_2D_ARRAY',0x8DC1)
GL_SAMPLER_2D_ARRAY_SHADOW=_C('GL_SAMPLER_2D_ARRAY_SHADOW',0x8DC4)
GL_SAMPLER_2D_SHADOW=_C('GL_SAMPLER_2D_SHADOW',0x8B62)
GL_SAMPLER_3D=_C('GL_SAMPLER_3D',0x8B5F)
GL_SAMPLER_BINDING=_C('GL_SAMPLER_BINDING',0x8919)
GL_SAMPLER_CUBE_SHADOW=_C('GL_SAMPLER_CUBE_SHADOW',0x8DC5)
GL_SEPARATE_ATTRIBS=_C('GL_SEPARATE_ATTRIBS',0x8C8D)
GL_SIGNALED=_C('GL_SIGNALED',0x9119)
GL_SIGNED_NORMALIZED=_C('GL_SIGNED_NORMALIZED',0x8F9C)
GL_SRGB=_C('GL_SRGB',0x8C40)
GL_SRGB8=_C('GL_SRGB8',0x8C41)
GL_SRGB8_ALPHA8=_C('GL_SRGB8_ALPHA8',0x8C43)
GL_STATIC_COPY=_C('GL_STATIC_COPY',0x88E6)
GL_STATIC_READ=_C('GL_STATIC_READ',0x88E5)
GL_STENCIL=_C('GL_STENCIL',0x1802)
GL_STREAM_COPY=_C('GL_STREAM_COPY',0x88E2)
GL_STREAM_READ=_C('GL_STREAM_READ',0x88E1)
GL_SYNC_CONDITION=_C('GL_SYNC_CONDITION',0x9113)
GL_SYNC_FENCE=_C('GL_SYNC_FENCE',0x9116)
GL_SYNC_FLAGS=_C('GL_SYNC_FLAGS',0x9115)
GL_SYNC_FLUSH_COMMANDS_BIT=_C('GL_SYNC_FLUSH_COMMANDS_BIT',0x00000001)
GL_SYNC_GPU_COMMANDS_COMPLETE=_C('GL_SYNC_GPU_COMMANDS_COMPLETE',0x9117)
GL_SYNC_STATUS=_C('GL_SYNC_STATUS',0x9114)
GL_TEXTURE_2D_ARRAY=_C('GL_TEXTURE_2D_ARRAY',0x8C1A)
GL_TEXTURE_3D=_C('GL_TEXTURE_3D',0x806F)
GL_TEXTURE_BASE_LEVEL=_C('GL_TEXTURE_BASE_LEVEL',0x813C)
GL_TEXTURE_BINDING_2D_ARRAY=_C('GL_TEXTURE_BINDING_2D_ARRAY',0x8C1D)
GL_TEXTURE_BINDING_3D=_C('GL_TEXTURE_BINDING_3D',0x806A)
GL_TEXTURE_COMPARE_FUNC=_C('GL_TEXTURE_COMPARE_FUNC',0x884D)
GL_TEXTURE_COMPARE_MODE=_C('GL_TEXTURE_COMPARE_MODE',0x884C)
GL_TEXTURE_IMMUTABLE_FORMAT=_C('GL_TEXTURE_IMMUTABLE_FORMAT',0x912F)
GL_TEXTURE_IMMUTABLE_LEVELS=_C('GL_TEXTURE_IMMUTABLE_LEVELS',0x82DF)
GL_TEXTURE_MAX_LEVEL=_C('GL_TEXTURE_MAX_LEVEL',0x813D)
GL_TEXTURE_MAX_LOD=_C('GL_TEXTURE_MAX_LOD',0x813B)
GL_TEXTURE_MIN_LOD=_C('GL_TEXTURE_MIN_LOD',0x813A)
GL_TEXTURE_SWIZZLE_A=_C('GL_TEXTURE_SWIZZLE_A',0x8E45)
GL_TEXTURE_SWIZZLE_B=_C('GL_TEXTURE_SWIZZLE_B',0x8E44)
GL_TEXTURE_SWIZZLE_G=_C('GL_TEXTURE_SWIZZLE_G',0x8E43)
GL_TEXTURE_SWIZZLE_R=_C('GL_TEXTURE_SWIZZLE_R',0x8E42)
GL_TEXTURE_WRAP_R=_C('GL_TEXTURE_WRAP_R',0x8072)
GL_TIMEOUT_EXPIRED=_C('GL_TIMEOUT_EXPIRED',0x911B)
GL_TIMEOUT_IGNORED=_C('GL_TIMEOUT_IGNORED',0xFFFFFFFFFFFFFFFF)
GL_TRANSFORM_FEEDBACK=_C('GL_TRANSFORM_FEEDBACK',0x8E22)
GL_TRANSFORM_FEEDBACK_ACTIVE=_C('GL_TRANSFORM_FEEDBACK_ACTIVE',0x8E24)
GL_TRANSFORM_FEEDBACK_BINDING=_C('GL_TRANSFORM_FEEDBACK_BINDING',0x8E25)
GL_TRANSFORM_FEEDBACK_BUFFER=_C('GL_TRANSFORM_FEEDBACK_BUFFER',0x8C8E)
GL_TRANSFORM_FEEDBACK_BUFFER_BINDING=_C('GL_TRANSFORM_FEEDBACK_BUFFER_BINDING',0x8C8F)
GL_TRANSFORM_FEEDBACK_BUFFER_MODE=_C('GL_TRANSFORM_FEEDBACK_BUFFER_MODE',0x8C7F)
GL_TRANSFORM_FEEDBACK_BUFFER_SIZE=_C('GL_TRANSFORM_FEEDBACK_BUFFER_SIZE',0x8C85)
GL_TRANSFORM_FEEDBACK_BUFFER_START=_C('GL_TRANSFORM_FEEDBACK_BUFFER_START',0x8C84)
GL_TRANSFORM_FEEDBACK_PAUSED=_C('GL_TRANSFORM_FEEDBACK_PAUSED',0x8E23)
GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN=_C('GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN',0x8C88)
GL_TRANSFORM_FEEDBACK_VARYINGS=_C('GL_TRANSFORM_FEEDBACK_VARYINGS',0x8C83)
GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH=_C('GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH',0x8C76)
GL_UNIFORM_ARRAY_STRIDE=_C('GL_UNIFORM_ARRAY_STRIDE',0x8A3C)
GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS=_C('GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS',0x8A42)
GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES=_C('GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES',0x8A43)
GL_UNIFORM_BLOCK_BINDING=_C('GL_UNIFORM_BLOCK_BINDING',0x8A3F)
GL_UNIFORM_BLOCK_DATA_SIZE=_C('GL_UNIFORM_BLOCK_DATA_SIZE',0x8A40)
GL_UNIFORM_BLOCK_INDEX=_C('GL_UNIFORM_BLOCK_INDEX',0x8A3A)
GL_UNIFORM_BLOCK_NAME_LENGTH=_C('GL_UNIFORM_BLOCK_NAME_LENGTH',0x8A41)
GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER=_C('GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER',0x8A46)
GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER=_C('GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER',0x8A44)
GL_UNIFORM_BUFFER=_C('GL_UNIFORM_BUFFER',0x8A11)
GL_UNIFORM_BUFFER_BINDING=_C('GL_UNIFORM_BUFFER_BINDING',0x8A28)
GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT=_C('GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT',0x8A34)
GL_UNIFORM_BUFFER_SIZE=_C('GL_UNIFORM_BUFFER_SIZE',0x8A2A)
GL_UNIFORM_BUFFER_START=_C('GL_UNIFORM_BUFFER_START',0x8A29)
GL_UNIFORM_IS_ROW_MAJOR=_C('GL_UNIFORM_IS_ROW_MAJOR',0x8A3E)
GL_UNIFORM_MATRIX_STRIDE=_C('GL_UNIFORM_MATRIX_STRIDE',0x8A3D)
GL_UNIFORM_NAME_LENGTH=_C('GL_UNIFORM_NAME_LENGTH',0x8A39)
GL_UNIFORM_OFFSET=_C('GL_UNIFORM_OFFSET',0x8A3B)
GL_UNIFORM_SIZE=_C('GL_UNIFORM_SIZE',0x8A38)
GL_UNIFORM_TYPE=_C('GL_UNIFORM_TYPE',0x8A37)
GL_UNPACK_IMAGE_HEIGHT=_C('GL_UNPACK_IMAGE_HEIGHT',0x806E)
GL_UNPACK_ROW_LENGTH=_C('GL_UNPACK_ROW_LENGTH',0x0CF2)
GL_UNPACK_SKIP_IMAGES=_C('GL_UNPACK_SKIP_IMAGES',0x806D)
GL_UNPACK_SKIP_PIXELS=_C('GL_UNPACK_SKIP_PIXELS',0x0CF4)
GL_UNPACK_SKIP_ROWS=_C('GL_UNPACK_SKIP_ROWS',0x0CF3)
GL_UNSIGNALED=_C('GL_UNSIGNALED',0x9118)
GL_UNSIGNED_INT_10F_11F_11F_REV=_C('GL_UNSIGNED_INT_10F_11F_11F_REV',0x8C3B)
GL_UNSIGNED_INT_24_8=_C('GL_UNSIGNED_INT_24_8',0x84FA)
GL_UNSIGNED_INT_2_10_10_10_REV=_C('GL_UNSIGNED_INT_2_10_10_10_REV',0x8368)
GL_UNSIGNED_INT_5_9_9_9_REV=_C('GL_UNSIGNED_INT_5_9_9_9_REV',0x8C3E)
GL_UNSIGNED_INT_SAMPLER_2D=_C('GL_UNSIGNED_INT_SAMPLER_2D',0x8DD2)
GL_UNSIGNED_INT_SAMPLER_2D_ARRAY=_C('GL_UNSIGNED_INT_SAMPLER_2D_ARRAY',0x8DD7)
GL_UNSIGNED_INT_SAMPLER_3D=_C('GL_UNSIGNED_INT_SAMPLER_3D',0x8DD3)
GL_UNSIGNED_INT_SAMPLER_CUBE=_C('GL_UNSIGNED_INT_SAMPLER_CUBE',0x8DD4)
GL_UNSIGNED_INT_VEC2=_C('GL_UNSIGNED_INT_VEC2',0x8DC6)
GL_UNSIGNED_INT_VEC3=_C('GL_UNSIGNED_INT_VEC3',0x8DC7)
GL_UNSIGNED_INT_VEC4=_C('GL_UNSIGNED_INT_VEC4',0x8DC8)
GL_UNSIGNED_NORMALIZED=_C('GL_UNSIGNED_NORMALIZED',0x8C17)
GL_VERTEX_ARRAY_BINDING=_C('GL_VERTEX_ARRAY_BINDING',0x85B5)
GL_VERTEX_ATTRIB_ARRAY_DIVISOR=_C('GL_VERTEX_ATTRIB_ARRAY_DIVISOR',0x88FE)
GL_VERTEX_ATTRIB_ARRAY_INTEGER=_C('GL_VERTEX_ATTRIB_ARRAY_INTEGER',0x88FD)
GL_WAIT_FAILED=_C('GL_WAIT_FAILED',0x911D)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBeginQuery(target,id):pass
@_f
@_p.types(None,_cs.GLenum)
def glBeginTransformFeedback(primitiveMode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint)
def glBindBufferBase(target,index,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr)
def glBindBufferRange(target,index,buffer,offset,size):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glBindSampler(unit,sampler):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindTransformFeedback(target,id):pass
@_f
@_p.types(None,_cs.GLuint)
def glBindVertexArray(array):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLbitfield,_cs.GLenum)
def glBlitFramebuffer(srcX0,srcY0,srcX1,srcY1,dstX0,dstY0,dstX1,dstY1,mask,filter):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLfloat,_cs.GLint)
def glClearBufferfi(buffer,drawbuffer,depth,stencil):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLfloatArray)
def glClearBufferfv(buffer,drawbuffer,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLintArray)
def glClearBufferiv(buffer,drawbuffer,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLuintArray)
def glClearBufferuiv(buffer,drawbuffer,value):pass
@_f
@_p.types(_cs.GLenum,_cs.GLsync,_cs.GLbitfield,_cs.GLuint64)
def glClientWaitSync(sync,flags,timeout):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLsizei,ctypes.c_void_p)
def glCompressedTexImage3D(target,level,internalformat,width,height,depth,border,imageSize,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glCompressedTexSubImage3D(target,level,xoffset,yoffset,zoffset,width,height,depth,format,imageSize,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLintptr,_cs.GLintptr,_cs.GLsizeiptr)
def glCopyBufferSubData(readTarget,writeTarget,readOffset,writeOffset,size):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glCopyTexSubImage3D(target,level,xoffset,yoffset,zoffset,x,y,width,height):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteQueries(n,ids):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteSamplers(count,samplers):pass
@_f
@_p.types(None,_cs.GLsync)
def glDeleteSync(sync):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteTransformFeedbacks(n,ids):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteVertexArrays(n,arrays):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glDrawArraysInstanced(mode,first,count,instancecount):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDrawBuffers(n,bufs):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p,_cs.GLsizei)
def glDrawElementsInstanced(mode,count,type,indices,instancecount):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p)
def glDrawRangeElements(mode,start,end,count,type,indices):pass
@_f
@_p.types(None,_cs.GLenum)
def glEndQuery(target):pass
@_f
@_p.types(None,)
def glEndTransformFeedback():pass
@_f
@_p.types(_cs.GLsync,_cs.GLenum,_cs.GLbitfield)
def glFenceSync(condition,flags):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr)
def glFlushMappedBufferRange(target,offset,length):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTextureLayer(target,attachment,texture,level,layer):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenQueries(n,ids):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenSamplers(count,samplers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenTransformFeedbacks(n,ids):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenVertexArrays(n,arrays):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetActiveUniformBlockName(program,uniformBlockIndex,bufSize,length,uniformBlockName):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetActiveUniformBlockiv(program,uniformBlockIndex,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,_cs.GLenum,arrays.GLintArray)
def glGetActiveUniformsiv(program,uniformCount,uniformIndices,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLint64Array)
def glGetBufferParameteri64v(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLvoidpArray)
def glGetBufferPointerv(target,pname,params):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,arrays.GLcharArray)
def glGetFragDataLocation(program,name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLint64Array)
def glGetInteger64i_v(target,index,data):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLint64Array)
def glGetInteger64v(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLintArray)
def glGetIntegeri_v(target,index,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLsizei,arrays.GLintArray)
def glGetInternalformativ(target,internalformat,pname,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLuintArray,ctypes.c_void_p)
def glGetProgramBinary(program,bufSize,length,binaryFormat,binary):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetQueryObjectuiv(id,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetQueryiv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetSamplerParameterfv(sampler,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetSamplerParameteriv(sampler,pname,params):pass
@_f
@_p.types(arrays.GLubyteArray,_cs.GLenum,_cs.GLuint)
def glGetStringi(name,index):pass
@_f
@_p.types(None,_cs.GLsync,_cs.GLenum,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray)
def glGetSynciv(sync,pname,bufSize,length,values):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLcharArray)
def glGetTransformFeedbackVarying(program,index,bufSize,length,size,type,name):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint,arrays.GLcharArray)
def glGetUniformBlockIndex(program,uniformBlockName):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )),arrays.GLuintArray)
def glGetUniformIndices(program,uniformCount,uniformNames,uniformIndices):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,arrays.GLuintArray)
def glGetUniformuiv(program,location,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVertexAttribIiv(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetVertexAttribIuiv(index,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray)
def glInvalidateFramebuffer(target,numAttachments,attachments):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glInvalidateSubFramebuffer(target,numAttachments,attachments,x,y,width,height):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsQuery(id):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsSampler(sampler):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLsync)
def glIsSync(sync):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsTransformFeedback(id):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsVertexArray(array):pass
@_f
@_p.types(ctypes.c_void_p,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr,_cs.GLbitfield)
def glMapBufferRange(target,offset,length,access):pass
@_f
@_p.types(None,)
def glPauseTransformFeedback():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,ctypes.c_void_p,_cs.GLsizei)
def glProgramBinary(program,binaryFormat,binary,length):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint)
def glProgramParameteri(program,pname,value):pass
@_f
@_p.types(None,_cs.GLenum)
def glReadBuffer(src):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glRenderbufferStorageMultisample(target,samples,internalformat,width,height):pass
@_f
@_p.types(None,)
def glResumeTransformFeedback():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLfloat)
def glSamplerParameterf(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glSamplerParameterfv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint)
def glSamplerParameteri(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glSamplerParameteriv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage3D(target,level,internalformat,width,height,depth,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glTexStorage2D(target,levels,internalformat,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei)
def glTexStorage3D(target,levels,internalformat,width,height,depth):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexSubImage3D(target,level,xoffset,yoffset,zoffset,width,height,depth,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )),_cs.GLenum)
def glTransformFeedbackVaryings(program,count,varyings,bufferMode):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint)
def glUniform1ui(location,v0):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform1uiv(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint)
def glUniform2ui(location,v0,v1):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform2uiv(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glUniform3ui(location,v0,v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform3uiv(location,count,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glUniform4ui(location,v0,v1,v2,v3):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glUniform4uiv(location,count,value):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glUniformBlockBinding(program,uniformBlockIndex,uniformBlockBinding):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix2x3fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix2x4fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix3x2fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix3x4fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix4x2fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix4x3fv(location,count,transpose,value):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum)
def glUnmapBuffer(target):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glVertexAttribDivisor(index,divisor):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertexAttribI4i(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttribI4iv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glVertexAttribI4ui(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttribI4uiv(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glVertexAttribIPointer(index,size,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLsync,_cs.GLbitfield,_cs.GLuint64)
def glWaitSync(sync,flags,timeout):pass



'''OpenGL extension NV.clip_space_w_scaling

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.clip_space_w_scaling to provide a more 
Python-friendly API

Overview (from the spec)
	
	Virtual Reality (VR) applications often involve a post-processing step to
	apply a "barrel" distortion to the rendered image to correct the
	"pincushion" distortion introduced by the optics in a VR device. The
	barrel distorted image has lower resolution along the edges compared to
	the center.  Since the original image is rendered at high resolution,
	which is uniform across the complete image, a lot of pixels towards the
	edges do not make it to the final post-processed image.
	
	This extension also provides a mechanism to render VR scenes at a
	non-uniform resolution, in particular a resolution that falls linearly
	from the center towards the edges.  This is achieved by scaling the "w"
	coordinate of the vertices in the clip space before perspective divide.
	The clip space "w" coordinate of the vertices may be offset as of a
	function of "x" and "y" coordinates as follows:
	
	        w' = w + Ax + By
	
	In the intended use case for viewport position scaling, an application
	should use a set of 4 viewports, one for each of the 4 quadrants of a
	Cartesian coordinate system.  Each viewport is set to the dimension of the
	image, but is scissored to the quadrant it represents.  The application
	should specify A and B coefficients of the w-scaling equation above,
	that have the same value, but different signs, for each of the viewports.
	The signs of A and B should match the signs of X and Y for the quadrant
	that they represent such that the value of "w'" will always be greater
	than or equal to the original "w" value for the entire image. Since the
	offset to "w", (Ax + By), is always positive and increases with the
	absolute values of "x" and "y", the effective resolution will fall off
	linearly from the center of the image to its edges.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/clip_space_w_scaling.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.clip_space_w_scaling import *
from OpenGL.raw.GLES2.NV.clip_space_w_scaling import _EXTENSION_NAME

def glInitClipSpaceWScalingNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


from ctypes import *
from ctypes import _SimpleCData, _check_size
from OpenGL import extensions
from OpenGL.raw.GL._types import *
from OpenGL._bytes import as_8_bit
from OpenGL._opaque import opaque_pointer_cls as _opaque_pointer_cls
c_void = None

class _WGLQuerier( extensions.ExtensionQuerier ):
    prefix = b'WGL_'
    assumed_version = [1,0]
    version_prefix = b'WGL_VERSION_WGL_'
    def pullVersion( self ):
        # only one version...
        return [1,0]
    def pullExtensions( self ):
        from OpenGL.platform import PLATFORM
        wglGetCurrentDC = PLATFORM.OpenGL.wglGetCurrentDC
        wglGetCurrentDC.restyle = HDC
        try:
            dc = wglGetCurrentDC()
            proc_address = PLATFORM.getExtensionProcedure(b'wglGetExtensionsStringARB')
            wglGetExtensionStringARB = PLATFORM.functionTypeFor( PLATFORM.WGL )(
                c_char_p,
                HDC,
            )( proc_address )
        except TypeError as err:
            return None
        except AttributeError as err:
            return []
        else:
            return wglGetExtensionStringARB(dc).split()
WGLQuerier=_WGLQuerier()

INT8 = c_char 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:35
PINT8 = c_char_p 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:35
INT16 = c_short 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:36
PINT16 = POINTER(c_short) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:36
INT32 = c_int 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:37
PINT32 = POINTER(c_int) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:37
UINT8 = c_ubyte 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:38
PUINT8 = POINTER(c_ubyte) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:38
UINT16 = c_ushort 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:39
PUINT16 = POINTER(c_ushort) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:39
UINT32 = c_uint 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:40
PUINT32 = POINTER(c_uint) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:40
LONG32 = c_int 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:41
PLONG32 = POINTER(c_int) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:41
ULONG32 = c_uint 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:42
PULONG32 = POINTER(c_uint) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:42
DWORD32 = c_uint 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:43
PDWORD32 = POINTER(c_uint) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:43
INT64 = c_longlong 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:44
PINT64 = POINTER(c_longlong) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:44
UINT64 = c_ulonglong 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:45
PUINT64 = POINTER(c_ulonglong) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:45
VOID = None 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:47
LPVOID = POINTER(None) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:47
LPCSTR = c_char_p 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:48
CHAR = c_char 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:49
BYTE = c_ubyte 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:50
WORD = c_ushort 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:51
USHORT = c_ushort 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:51
UINT = c_uint 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:52
INT = c_int 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:53
INT_PTR = POINTER(c_int) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:53
BOOL = c_long 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:54
LONG = c_long 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:55
DWORD = c_ulong 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:56
FLOAT = c_float 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:57
COLORREF = DWORD 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:58
LPCOLORREF = POINTER(DWORD) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:58

#HANDLE = POINTER(None) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:60
# TODO: figure out how to make the handle not appear as a void_p within the code...
# This decorates *every* c_void_p reference, as ctypes now reuses the references
# which means it completely disables all of the array-handing machinery
class HANDLE(_SimpleCData):
    """Github Issue #8 CTypes shares all references to c_void_p
    
    We have to have a separate type to avoid short-circuiting all
    of the array-handling machinery for real c_void_p arguments.
    """
    _type_ = "P"
_check_size(HANDLE)
HANDLE.final = True

HGLRC = HANDLE 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:62
HDC = HANDLE 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:63
PROC = CFUNCTYPE(INT_PTR) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:65
HPBUFFERARB = HANDLE
HPBUFFEREXT = HANDLE

class struct__POINTFLOAT(Structure):
    __slots__ = [
        'x',
        'y',
    ]
struct__POINTFLOAT._fields_ = [
    ('x', FLOAT),
    ('y', FLOAT),
]

POINTFLOAT = struct__POINTFLOAT 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:83
PPOINTFLOAT = POINTER(struct__POINTFLOAT) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:83
class struct__GLYPHMETRICSFLOAT(Structure):
    __slots__ = [
        'gmfBlackBoxX',
        'gmfBlackBoxY',
        'gmfptGlyphOrigin',
        'gmfCellIncX',
        'gmfCellIncY',
    ]
struct__GLYPHMETRICSFLOAT._fields_ = [
    ('gmfBlackBoxX', FLOAT),
    ('gmfBlackBoxY', FLOAT),
    ('gmfptGlyphOrigin', POINTFLOAT),
    ('gmfCellIncX', FLOAT),
    ('gmfCellIncY', FLOAT),
]

GLYPHMETRICSFLOAT = struct__GLYPHMETRICSFLOAT 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:91
PGLYPHMETRICSFLOAT = POINTER(struct__GLYPHMETRICSFLOAT) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:91
LPGLYPHMETRICSFLOAT = POINTER(struct__GLYPHMETRICSFLOAT) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:91

class struct_tagLAYERPLANEDESCRIPTOR(Structure):
    __slots__ = [
        'nSize',
        'nVersion',
        'dwFlags',
        'iPixelType',
        'cColorBits',
        'cRedBits',
        'cRedShift',
        'cGreenBits',
        'cGreenShift',
        'cBlueBits',
        'cBlueShift',
        'cAlphaBits',
        'cAlphaShift',
        'cAccumBits',
        'cAccumRedBits',
        'cAccumGreenBits',
        'cAccumBlueBits',
        'cAccumAlphaBits',
        'cDepthBits',
        'cStencilBits',
        'cAuxBuffers',
        'iLayerPlane',
        'bReserved',
        'crTransparent',
    ]
struct_tagLAYERPLANEDESCRIPTOR._fields_ = [
    ('nSize', WORD),
    ('nVersion', WORD),
    ('dwFlags', DWORD),
    ('iPixelType', BYTE),
    ('cColorBits', BYTE),
    ('cRedBits', BYTE),
    ('cRedShift', BYTE),
    ('cGreenBits', BYTE),
    ('cGreenShift', BYTE),
    ('cBlueBits', BYTE),
    ('cBlueShift', BYTE),
    ('cAlphaBits', BYTE),
    ('cAlphaShift', BYTE),
    ('cAccumBits', BYTE),
    ('cAccumRedBits', BYTE),
    ('cAccumGreenBits', BYTE),
    ('cAccumBlueBits', BYTE),
    ('cAccumAlphaBits', BYTE),
    ('cDepthBits', BYTE),
    ('cStencilBits', BYTE),
    ('cAuxBuffers', BYTE),
    ('iLayerPlane', BYTE),
    ('bReserved', BYTE),
    ('crTransparent', COLORREF),
]

LAYERPLANEDESCRIPTOR = struct_tagLAYERPLANEDESCRIPTOR 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:127
PLAYERPLANEDESCRIPTOR = POINTER(struct_tagLAYERPLANEDESCRIPTOR) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:127
LPLAYERPLANEDESCRIPTOR = POINTER(struct_tagLAYERPLANEDESCRIPTOR) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:127

class struct__WGLSWAP(Structure):
    __slots__ = [
        'hdc',
        'uiFlags',
    ]
struct__WGLSWAP._fields_ = [
    ('hdc', HDC),
    ('uiFlags', UINT),
]

WGLSWAP = struct__WGLSWAP 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:190
PWGLSWAP = POINTER(struct__WGLSWAP) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:190
LPWGLSWAP = POINTER(struct__WGLSWAP) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:190

class struct_tagRECT(Structure):
    __slots__ = [
        'left',
        'top',
        'right',
        'bottom',
    ]
struct_tagRECT._fields_ = [
    ('left', LONG),
    ('top', LONG),
    ('right', LONG),
    ('bottom', LONG),
]

RECT = struct_tagRECT 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:202
PRECT = POINTER(struct_tagRECT) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:202
NPRECT = POINTER(struct_tagRECT) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:202
LPRECT = POINTER(struct_tagRECT) 	# /home/mcfletch/pylive/OpenGL-ctypes/src/wgl.h:202

class PIXELFORMATDESCRIPTOR(Structure):
    _fields_ = [
        ('nSize',WORD),
        ('nVersion',WORD),
        ('dwFlags',DWORD),
        ('iPixelType',BYTE),
        ('cColorBits',BYTE),
        ('cRedBits',BYTE),
        ('cRedShift',BYTE),
        ('cGreenBits',BYTE),
        ('cGreenShift',BYTE),
        ('cBlueBits',BYTE),
        ('cBlueShift',BYTE),
        ('cAlphaBits',BYTE),
        ('cAlphaShift',BYTE),
        ('cAccumBits',BYTE),
        ('cAccumRedBits',BYTE),
        ('cAccumGreenBits',BYTE),
        ('cAccumBlueBits',BYTE),
        ('cAccumAlphaBits',BYTE),
        ('cAccumDepthBits',BYTE),
        ('cAccumStencilBits',BYTE),
        ('cAuxBuffers',BYTE),
        ('iLayerType',BYTE),
        ('bReserved',BYTE),
        ('dwLayerMask',DWORD),
        ('dwVisibleMask',DWORD),
        ('dwDamageMask',DWORD),
    ]

# TODO: This is *not* a working definition, calling any function with this will segfault
HENHMETAFILE = _opaque_pointer_cls( 'HENHMETAFILE' )



'''OpenGL extension ANGLE.texture_usage

This module customises the behaviour of the 
OpenGL.raw.GLES2.ANGLE.texture_usage to provide a more 
Python-friendly API

Overview (from the spec)
	
	In some implementations it is advantageous to know the expected
	usage of a texture before the backing storage for it is allocated.  
	This can help to inform the implementation's choice of format
	and type of memory used for the allocation. If the usage is not
	known in advance, the implementation essentially has to make a 
	guess as to how it will be used.  If it is later proven wrong,
	it may need to perform costly re-allocations and/or reformatting 
	of the texture data, resulting in reduced performance.
	
	This extension adds a texture usage flag that is specified via
	the TEXTURE_USAGE_ANGLE TexParameter.  This can be used to 
	indicate that the application knows that this texture will be 
	used for rendering.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ANGLE/texture_usage.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.ANGLE.texture_usage import *
from OpenGL.raw.GLES2.ANGLE.texture_usage import _EXTENSION_NAME

def glInitTextureUsageANGLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.sample_locations

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.sample_locations to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows an application to modify the locations of samples
	within a pixel used in multisample rasterization.  Additionally, it allows
	applications to specify different sample locations for each pixel in a
	group of adjacent pixels, which may increase antialiasing quality
	(particularly if a custom resolve shader is used that takes advantage of
	these different locations).
	
	It is common for implementations to optimize the storage of depth values
	by storing values that can be used to reconstruct depth at each sample
	location, rather than storing separate depth values for each sample. For
	example, the depth values from a single triangle can be represented using
	plane equations.  When the depth value for a sample is needed, it is
	automatically evaluated at the sample location. Modifying the sample
	locations causes the reconstruction to no longer evaluate the same depth
	values as when the samples were originally generated.  This extension
	provides a command to "evaluate" and store per-sample depth values using
	the currently programmed sample locations, which allows the application to
	manage this issue if/when necessary.
	
	The programmable sample locations are used during rasterization and for
	evaluation of depth functions during normal geometric rendering. The
	programmable locations are associated with a framebuffer object rather
	than an individual depth buffer, so if the depth buffer is used as a
	texture the texture sampling may be done at the standard sample
	locations. Additionally, commands that do not render geometric primitives
	(e.g. ReadPixels, BlitFramebuffer, CopyTexSubImage2D, etc.) may use the
	standard sample locations to evaluate depth functions rather than the
	programmable locations. If a single depth buffer is used at different
	times with different sample locations, the depth functions may be
	interpreted using the current sample locations.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/sample_locations.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.sample_locations import *
from OpenGL.raw.GL.ARB.sample_locations import _EXTENSION_NAME

def glInitSampleLocationsARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SUN.vertex

This module customises the behaviour of the 
OpenGL.raw.GL.SUN.vertex to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides new GL commands to specify vertex data such as 
	color and normal along with the vertex in one single GL command in order to
	minimize the overhead in making GL commands for each set of vertex data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SUN/vertex.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SUN.vertex import *
from OpenGL.raw.GL.SUN.vertex import _EXTENSION_NAME

def glInitVertexSUN():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glColor4ubVertex2fvSUN=wrapper.wrapper(glColor4ubVertex2fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'v', 2
)
glColor4ubVertex3fvSUN=wrapper.wrapper(glColor4ubVertex3fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'v', 3
)
glColor3fVertex3fvSUN=wrapper.wrapper(glColor3fVertex3fvSUN).setInputArraySize(
    'c', 3
).setInputArraySize(
    'v', 3
)
glNormal3fVertex3fvSUN=wrapper.wrapper(glNormal3fVertex3fvSUN).setInputArraySize(
    'n', 3
).setInputArraySize(
    'v', 3
)
glColor4fNormal3fVertex3fvSUN=wrapper.wrapper(glColor4fNormal3fVertex3fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'n', 3
).setInputArraySize(
    'v', 3
)
glTexCoord2fVertex3fvSUN=wrapper.wrapper(glTexCoord2fVertex3fvSUN).setInputArraySize(
    'tc', 2
).setInputArraySize(
    'v', 3
)
glTexCoord4fVertex4fvSUN=wrapper.wrapper(glTexCoord4fVertex4fvSUN).setInputArraySize(
    'tc', 4
).setInputArraySize(
    'v', 4
)
glTexCoord2fColor4ubVertex3fvSUN=wrapper.wrapper(glTexCoord2fColor4ubVertex3fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'tc', 2
).setInputArraySize(
    'v', 3
)
glTexCoord2fColor3fVertex3fvSUN=wrapper.wrapper(glTexCoord2fColor3fVertex3fvSUN).setInputArraySize(
    'c', 3
).setInputArraySize(
    'tc', 2
).setInputArraySize(
    'v', 3
)
glTexCoord2fNormal3fVertex3fvSUN=wrapper.wrapper(glTexCoord2fNormal3fVertex3fvSUN).setInputArraySize(
    'n', 3
).setInputArraySize(
    'tc', 2
).setInputArraySize(
    'v', 3
)
glTexCoord2fColor4fNormal3fVertex3fvSUN=wrapper.wrapper(glTexCoord2fColor4fNormal3fVertex3fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'n', 3
).setInputArraySize(
    'tc', 2
).setInputArraySize(
    'v', 3
)
glTexCoord4fColor4fNormal3fVertex4fvSUN=wrapper.wrapper(glTexCoord4fColor4fNormal3fVertex4fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'n', 3
).setInputArraySize(
    'tc', 4
).setInputArraySize(
    'v', 4
)
glReplacementCodeuiVertex3fvSUN=wrapper.wrapper(glReplacementCodeuiVertex3fvSUN).setInputArraySize(
    'rc', 1
).setInputArraySize(
    'v', 3
)
glReplacementCodeuiColor4ubVertex3fvSUN=wrapper.wrapper(glReplacementCodeuiColor4ubVertex3fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'rc', 1
).setInputArraySize(
    'v', 3
)
glReplacementCodeuiColor3fVertex3fvSUN=wrapper.wrapper(glReplacementCodeuiColor3fVertex3fvSUN).setInputArraySize(
    'c', 3
).setInputArraySize(
    'rc', 1
).setInputArraySize(
    'v', 3
)
glReplacementCodeuiNormal3fVertex3fvSUN=wrapper.wrapper(glReplacementCodeuiNormal3fVertex3fvSUN).setInputArraySize(
    'n', 3
).setInputArraySize(
    'rc', 1
).setInputArraySize(
    'v', 3
)
glReplacementCodeuiColor4fNormal3fVertex3fvSUN=wrapper.wrapper(glReplacementCodeuiColor4fNormal3fVertex3fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'n', 3
).setInputArraySize(
    'rc', 1
).setInputArraySize(
    'v', 3
)
glReplacementCodeuiTexCoord2fVertex3fvSUN=wrapper.wrapper(glReplacementCodeuiTexCoord2fVertex3fvSUN).setInputArraySize(
    'rc', 1
).setInputArraySize(
    'tc', 2
).setInputArraySize(
    'v', 3
)
glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN=wrapper.wrapper(glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN).setInputArraySize(
    'n', 3
).setInputArraySize(
    'rc', 1
).setInputArraySize(
    'tc', 2
).setInputArraySize(
    'v', 3
)
glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN=wrapper.wrapper(glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN).setInputArraySize(
    'c', 4
).setInputArraySize(
    'n', 3
).setInputArraySize(
    'rc', 1
).setInputArraySize(
    'tc', 2
).setInputArraySize(
    'v', 3
)
### END AUTOGENERATED SECTION


'''OpenGL extension OES.get_program_binary

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.get_program_binary to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces two new commands.  GetProgramBinaryOES empowers an
	application to use the GL itself as an offline compiler.  The resulting
	program binary can be reloaded into the GL via ProgramBinaryOES.  This is a
	very useful path for applications that wish to remain portable by shipping
	pure GLSL source shaders, yet would like to avoid the cost of compiling
	their shaders at runtime.  Instead an application can supply its GLSL source
	shaders during first application run, or even during installation.  The
	application then compiles and links its shaders and reads back the program
	binaries.  On subsequent runs, only the program binaries need be supplied!
	Though the level of optimization may not be identical -- the offline shader
	compiler may have the luxury of more aggressive optimization at its
	disposal -- program binaries generated online by the GL are interchangeable
	with those generated offline by an SDK tool.
	
	Note that an implementation supporting this extension need not include an
	online compiler.  That is, it is not required to support loading GLSL shader
	sources via the ShaderSource command.  A query of boolean value
	SHADER_COMPILER can be used to determine if an implementation supports a
	shader compiler.  If not, the GetProgramBinaryOES command is rendered
	virtually useless, but the ProgramBinaryOES command may still be used by
	vendor extensions as a standard method for loading offline-compiled program
	binaries.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/get_program_binary.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.get_program_binary import *
from OpenGL.raw.GLES2.OES.get_program_binary import _EXTENSION_NAME

def glInitGetProgramBinaryOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGetProgramBinaryOES.binary size not checked against bufSize
glGetProgramBinaryOES=wrapper.wrapper(glGetProgramBinaryOES).setInputArraySize(
    'binary', None
).setInputArraySize(
    'binaryFormat', 1
).setInputArraySize(
    'length', 1
)
# INPUT glProgramBinaryOES.binary size not checked against length
glProgramBinaryOES=wrapper.wrapper(glProgramBinaryOES).setInputArraySize(
    'binary', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_draw_vulkan_image'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_draw_vulkan_image',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLuint64,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glDrawVkImageNV(vkImage,sampler,x0,y0,x1,y1,z,s0,t0,s1,t1):pass
@_f
@_p.types(_cs.GLVULKANPROCNV,arrays.GLcharArray)
def glGetVkProcAddrNV(name):pass
@_f
@_p.types(None,_cs.GLuint64)
def glSignalVkFenceNV(vkFence):pass
@_f
@_p.types(None,_cs.GLuint64)
def glSignalVkSemaphoreNV(vkSemaphore):pass
@_f
@_p.types(None,_cs.GLuint64)
def glWaitVkSemaphoreNV(vkSemaphore):pass



'''OpenGL extension EXT.primitive_bounding_box

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.primitive_bounding_box to provide a more 
Python-friendly API

Overview (from the spec)
	
	On tile-based architectures, transformed primitives are generally written
	out to memory before rasterization, and then read back from memory for each
	tile they intersect. When geometry expands during transformation due to
	tessellation or one-to-many geometry shaders, the external bandwidth
	required grows proportionally. This extension provides a way for
	implementations to know which tiles incoming geometry will intersect before
	fully transforming (and expanding) the geometry. This allows them to only
	store the unexpanded geometry in memory, and perform expansion on-chip for
	each intersected tile.
	
	New state is added to hold an axis-aligned bounding box which is assumed to
	contain any geometry submitted. An implementation is allowed to ignore any
	portions of primitives outside the bounding box; thus if a primitive extends
	outside of a tile into a neighboring tile that the bounding box didn't
	intersect, the implementation is not required to render those portions. The
	tessellation control shader is optionally able to specify a per-patch
	bounding box that overrides the bounding box state for primitives generated
	from that patch, in order to provide tighter bounds.
	
	The typical usage is that an application will have an object-space bounding
	volume for a primitive or group of primitives, either calculated at runtime
	or provided with the mesh by the authoring tool or content pipeline. It will
	transform this volume to clip space, compute an axis-aligned bounding box
	that contains the transformed bounding volume, and provide that at either
	per-patch or per-draw granularity.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/primitive_bounding_box.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.primitive_bounding_box import *
from OpenGL.raw.GLES2.EXT.primitive_bounding_box import _EXTENSION_NAME

def glInitPrimitiveBoundingBoxEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.clip_cull_distance

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.clip_cull_distance to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds support for hardware clip planes and cull
	distances to OpenGL ES. The language for this extension is based
	on the OpenGL 4.5 API Specification (May 28, 2015) and
	ARB_clip_distance.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/clip_cull_distance.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.clip_cull_distance import *
from OpenGL.raw.GLES2.EXT.clip_cull_distance import _EXTENSION_NAME

def glInitClipCullDistanceEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.representative_fragment_test

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.representative_fragment_test to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new _representative fragment test_ that allows
	implementations to reduce the amount of rasterization and fragment
	processing work performed for each point, line, or triangle primitive. For
	any primitive that produces one or more fragments that pass all other
	early fragment tests, the implementation is permitted to choose one or
	more "representative" fragments for processing and discard all other
	fragments. For draw calls rendering multiple points, lines, or triangles
	arranged in lists, strips, or fans, the representative fragment test is
	performed independently for each of those primitives.
	
	This extension is useful for applications that use an early render pass
	to determine the full set of primitives that would be visible in the final
	scene. In this render pass, such applications would set up a fragment
	shader that enables early fragment tests and writes to an image or shader
	storage buffer to record the ID of the primitive that generated the
	fragment. Without this extension, the shader would record the ID
	separately for each visible fragment of each primitive. With this
	extension, fewer stores will be performed, particularly for large
	primitives.
	
	The representative fragment test has no effect if early fragment tests are
	not enabled via the fragment shader. The set of fragments discarded by the
	representative fragment test is implementation-dependent and may vary from
	frame to frame. In some cases, the representative fragment test may not
	discard any fragments for a given primitive.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/representative_fragment_test.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.representative_fragment_test import *
from OpenGL.raw.GLES2.NV.representative_fragment_test import _EXTENSION_NAME

def glInitRepresentativeFragmentTestNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ANDROID.extension_pack_es31a

This module customises the behaviour of the 
OpenGL.raw.GLES2.ANDROID.extension_pack_es31a to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension changes little functionality directly. Instead it serves to
	roll up the 20 extensions it requires, allowing applications to check for
	all of them at once, and enable all of their shading language features with
	a single #extension statement. The Android platform provides special support
	outside of OpenGL ES to help applications target this set of extensions.
	
	In addition, this extension ensures support for images, shader storage
	buffers, and atomic counters in fragment shaders. In unextended OpenGL ES
	the minimum value of the relevant implementation-defined limits is zero;
	this extension raises these minimums to match the minimums for compute
	shaders.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ANDROID/extension_pack_es31a.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.ANDROID.extension_pack_es31a import *
from OpenGL.raw.GLES2.ANDROID.extension_pack_es31a import _EXTENSION_NAME

def glInitExtensionPackEs31AANDROID():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_shader_subroutine'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_shader_subroutine',error_checker=_errors._error_checker)
GL_ACTIVE_SUBROUTINES=_C('GL_ACTIVE_SUBROUTINES',0x8DE5)
GL_ACTIVE_SUBROUTINE_MAX_LENGTH=_C('GL_ACTIVE_SUBROUTINE_MAX_LENGTH',0x8E48)
GL_ACTIVE_SUBROUTINE_UNIFORMS=_C('GL_ACTIVE_SUBROUTINE_UNIFORMS',0x8DE6)
GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS=_C('GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS',0x8E47)
GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH=_C('GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH',0x8E49)
GL_COMPATIBLE_SUBROUTINES=_C('GL_COMPATIBLE_SUBROUTINES',0x8E4B)
GL_MAX_SUBROUTINES=_C('GL_MAX_SUBROUTINES',0x8DE7)
GL_MAX_SUBROUTINE_UNIFORM_LOCATIONS=_C('GL_MAX_SUBROUTINE_UNIFORM_LOCATIONS',0x8DE8)
GL_NUM_COMPATIBLE_SUBROUTINES=_C('GL_NUM_COMPATIBLE_SUBROUTINES',0x8E4A)
GL_UNIFORM_NAME_LENGTH=_C('GL_UNIFORM_NAME_LENGTH',0x8A39)
GL_UNIFORM_SIZE=_C('GL_UNIFORM_SIZE',0x8A38)
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetActiveSubroutineName(program,shadertype,index,bufsize,length,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLcharArray)
def glGetActiveSubroutineUniformName(program,shadertype,index,bufsize,length,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetActiveSubroutineUniformiv(program,shadertype,index,pname,values):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetProgramStageiv(program,shadertype,pname,values):pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLcharArray)
def glGetSubroutineIndex(program,shadertype,name):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,_cs.GLenum,arrays.GLcharArray)
def glGetSubroutineUniformLocation(program,shadertype,name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLuintArray)
def glGetUniformSubroutineuiv(shadertype,location,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray)
def glUniformSubroutinesuiv(shadertype,count,indices):pass



'''OpenGL extension MESA.tile_raster_order

This module customises the behaviour of the 
OpenGL.raw.GL.MESA.tile_raster_order to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the sampling-from-the-framebuffer behavior provided
	by GL_ARB_texture_barrier to allow setting the rasterization order of the
	scene, so that overlapping blits can be implemented.  This can be used for
	scrolling or window movement within in 2D scenes, without first copying to
	a temporary.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/MESA/tile_raster_order.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.MESA.tile_raster_order import *
from OpenGL.raw.GL.MESA.tile_raster_order import _EXTENSION_NAME

def glInitTileRasterOrderMESA():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_draw_elements_base_vertex'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_draw_elements_base_vertex',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p,_cs.GLint)
def glDrawElementsBaseVertexOES(mode,count,type,indices,basevertex):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p,_cs.GLsizei,_cs.GLint)
def glDrawElementsInstancedBaseVertexOES(mode,count,type,indices,instancecount,basevertex):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p,_cs.GLint)
def glDrawRangeElementsBaseVertexOES(mode,start,end,count,type,indices,basevertex):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLsizeiArray,_cs.GLenum,arrays.GLvoidpArray,_cs.GLsizei,arrays.GLintArray)
def glMultiDrawElementsBaseVertexEXT(mode,count,type,indices,primcount,basevertex):pass



'''OpenGL extension NV.explicit_attrib_location

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.explicit_attrib_location to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a method to pre-assign attribute locations
	to named vertex shader inputs.  This allows applications to globally
	assign a particular semantic meaning, such as diffuse color or
	vertex normal, to a particular attribute location without knowing
	how that attribute will be named in any particular shader.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/explicit_attrib_location.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.explicit_attrib_location import *
from OpenGL.raw.GLES2.NV.explicit_attrib_location import _EXTENSION_NAME

def glInitExplicitAttribLocationNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.texture_packed_float

This module customises the behaviour of the 
OpenGL.raw.GLES2.APPLE.texture_packed_float to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds two new 3-component floating-point texture formats
	that fit within a single 32-bit word called R11F_G11F_B10F and RGB9_E5 
	
	The first RGB format, R11F_G11F_B10F, stores 5 bits of biased exponent 
	per component in the same manner as 16-bit floating-point formats, but 
	rather than 10 mantissa bits, the red, green, and blue components have 
	6, 6, and 5 bits respectively. Each mantissa is assumed to have an 
	implied leading one except in the denorm exponent case.  There is no 
	sign bit so only non-negative values can be represented.  Positive 
	infinity, positivedenorms, and positive NaN values are representable.  
	The value of the fourth component returned by a texture fetch is always
	1.0.
	
	The second RGB format, RGB9_E5, stores a single 5-bit exponent (biased 
	up by 15) and three 9-bit mantissas for each respective component.  
	There is no sign bit so all three components must be non-negative.  
	The fractional mantissas are stored without an implied 1 to the left 
	of the decimal point. Neither infinity nor not-a-number (NaN) are 
	representable in this shared exponent format.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/texture_packed_float.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.APPLE.texture_packed_float import *
from OpenGL.raw.GLES2.APPLE.texture_packed_float import _EXTENSION_NAME

def glInitTexturePackedFloatAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.standard_derivatives

This module customises the behaviour of the 
OpenGL.raw.GLSC2.OES.standard_derivatives to provide a more 
Python-friendly API

Overview (from the spec)
	
	The standard derivative built-in functions and semantics from OpenGL 2.0 are
	optional for OpenGL ES 2.0.  When this extension is available, these
	built-in functions are also available, as is a hint controlling the
	quality/performance trade off.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/standard_derivatives.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLSC2 import _types, _glgets
from OpenGL.raw.GLSC2.OES.standard_derivatives import *
from OpenGL.raw.GLSC2.OES.standard_derivatives import _EXTENSION_NAME

def glInitStandardDerivativesOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.draw_texture

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.draw_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a mechanism for writing pixel
	rectangles from one or more textures to a rectangular
	region of the screen.  This capability is useful for
	fast rendering of background paintings, bitmapped font
	glyphs, and 2D framing elements in games.  This
	extension is primarily intended for use with OpenGL ES.
	
	The extension relies on a new piece of texture state
	called the texture crop rectangle, which defines a
	rectangular subregion of a texture object.  These
	subregions are used as sources of pixels for the texture
	drawing function.
	
	Applications use this extension by configuring the
	texture crop rectangle for one or more textures via
	ActiveTexture() and TexParameteriv() with pname equal to
	TEXTURE_CROP_RECT_OES.  They then request a drawing
	operation using DrawTex{sifx}[v]OES().  The effect of
	the latter function is to generate a screen-aligned
	target rectangle, with texture coordinates chosen to map
	the texture crop rectangle(s) linearly to fragments in
	the target rectangle.  The fragments are then processed
	in accordance with the fragment pipeline state.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/draw_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.draw_texture import *
from OpenGL.raw.GLES1.OES.draw_texture import _EXTENSION_NAME

def glInitDrawTextureOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glDrawTexsvOES=wrapper.wrapper(glDrawTexsvOES).setInputArraySize(
    'coords', 5
)
glDrawTexivOES=wrapper.wrapper(glDrawTexivOES).setInputArraySize(
    'coords', 5
)
glDrawTexxvOES=wrapper.wrapper(glDrawTexxvOES).setInputArraySize(
    'coords', 5
)
glDrawTexfvOES=wrapper.wrapper(glDrawTexfvOES).setInputArraySize(
    'coords', 5
)
### END AUTOGENERATED SECTION